@@ -3,16 +3,21 @@ package Module::Install::Repository;
 use strict;
 use 5.005;
 use vars qw($VERSION);
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 use base qw(Module::Install::Base);
 
+sub _execute {
+    my ($command) = @_;
+    `$command`;
+}
+
 sub auto_set_repository {
     my $self = shift;
 
     return unless $Module::Install::AUTHOR;
 
-    my $repo = _find_repo();
+    my $repo = _find_repo(\&_execute);
     if ($repo) {
         $self->repository($repo);
     } else {
@@ -21,14 +26,16 @@ sub auto_set_repository {
 }
 
 sub _find_repo {
+    my ($execute) = @_;
+
     if (-e ".git") {
         # TODO support remote besides 'origin'?
-        if (`git remote show origin` =~ /URL: (.*)$/m) {
+        if ($execute->('git remote show -n origin') =~ /URL: (.*)$/m) {
             # XXX Make it public clone URL, but this only works with github
             my $git_url = $1;
             $git_url =~ s![\w\-]+\@([^:]+):!git://$1/!;
             return $git_url;
-        } elsif (`git svn info` =~ /URL: (.*)$/m) {
+        } elsif ($execute->('git svn info') =~ /URL: (.*)$/m) {
             return $1;
         }
     } elsif (-e ".svn") {
@@ -48,6 +55,12 @@ sub _find_repo {
             chomp;
             return $_ if m!^http://!;
         }
+    } elsif (-e ".hg") {
+        if ($execute->('hg paths') =~ /default = (.*)$/m) {
+            my $mercurial_url = $1;
+            $mercurial_url =~ s!^ssh://hg\@(bitbucket\.org/)!https://$1!;
+            return $mercurial_url;
+        }
     } elsif (-e "$ENV{HOME}/.svk") {
         # Is there an explicit way to check if it's an svk checkout?
         my $svk_info = `svk info` or return;
